import onebusaway


def main_sync() -> None:
    client = onebusaway.OnebusawaySDK(api_key="TEST")

    trip_id = "40_608344966"
    trip = client.trip.retrieve(trip_id)

    if trip.data and trip.data.entry:
        print(trip.data.entry)
    else:
        print("trip data or entry is None.")


if __name__ == "__main__":
    main_sync()



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from pydantic import Field as FieldInfo

from .._models import BaseModel
from .shared.references import References
from .shared.response_wrapper import ResponseWrapper

__all__ = ["AgencyRetrieveResponse", "AgencyRetrieveResponseData", "AgencyRetrieveResponseDataEntry"]


class AgencyRetrieveResponseDataEntry(BaseModel):
    id: str

    name: str

    timezone: str

    url: str

    disclaimer: Optional[str] = None

    email: Optional[str] = None

    fare_url: Optional[str] = FieldInfo(alias="fareUrl", default=None)

    lang: Optional[str] = None

    phone: Optional[str] = None

    private_service: Optional[bool] = FieldInfo(alias="privateService", default=None)


class AgencyRetrieveResponseData(BaseModel):
    entry: AgencyRetrieveResponseDataEntry

    limit_exceeded: bool = FieldInfo(alias="limitExceeded")

    references: References


class AgencyRetrieveResponse(ResponseWrapper):
    data: AgencyRetrieveResponseData



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import trips_for_route_list_params
from .._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from .._utils import (
    maybe_transform,
    async_maybe_transform,
)
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.trips_for_route_list_response import TripsForRouteListResponse

__all__ = ["TripsForRouteResource", "AsyncTripsForRouteResource"]


class TripsForRouteResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> TripsForRouteResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/OneBusAway/python-sdk#accessing-raw-response-data-eg-headers
        """
        return TripsForRouteResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> TripsForRouteResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/OneBusAway/python-sdk#with_streaming_response
        """
        return TripsForRouteResourceWithStreamingResponse(self)

    def list(
        self,
        route_id: str,
        *,
        include_schedule: bool | NotGiven = NOT_GIVEN,
        include_status: bool | NotGiven = NOT_GIVEN,
        time: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> TripsForRouteListResponse:
        """
        Search for active trips for a specific route.

        Args:
          include_schedule: Determine whether full schedule elements are included. Defaults to false.

          include_status: Determine whether full tripStatus elements with real-time information are
              included. Defaults to false.

          time: Query the system at a specific time. Useful for testing.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not route_id:
            raise ValueError(f"Expected a non-empty value for `route_id` but received {route_id!r}")
        return self._get(
            f"/api/where/trips-for-route/{route_id}.json",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "include_schedule": include_schedule,
                        "include_status": include_status,
                        "time": time,
                    },
                    trips_for_route_list_params.TripsForRouteListParams,
                ),
            ),
            cast_to=TripsForRouteListResponse,
        )


class AsyncTripsForRouteResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncTripsForRouteResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/OneBusAway/python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncTripsForRouteResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncTripsForRouteResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/OneBusAway/python-sdk#with_streaming_response
        """
        return AsyncTripsForRouteResourceWithStreamingResponse(self)

    async def list(
        self,
        route_id: str,
        *,
        include_schedule: bool | NotGiven = NOT_GIVEN,
        include_status: bool | NotGiven = NOT_GIVEN,
        time: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> TripsForRouteListResponse:
        """
        Search for active trips for a specific route.

        Args:
          include_schedule: Determine whether full schedule elements are included. Defaults to false.

          include_status: Determine whether full tripStatus elements with real-time information are
              included. Defaults to false.

          time: Query the system at a specific time. Useful for testing.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not route_id:
            raise ValueError(f"Expected a non-empty value for `route_id` but received {route_id!r}")
        return await self._get(
            f"/api/where/trips-for-route/{route_id}.json",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "include_schedule": include_schedule,
                        "include_status": include_status,
                        "time": time,
                    },
                    trips_for_route_list_params.TripsForRouteListParams,
                ),
            ),
            cast_to=TripsForRouteListResponse,
        )


class TripsForRouteResourceWithRawResponse:
    def __init__(self, trips_for_route: TripsForRouteResource) -> None:
        self._trips_for_route = trips_for_route

        self.list = to_raw_response_wrapper(
            trips_for_route.list,
        )


class AsyncTripsForRouteResourceWithRawResponse:
    def __init__(self, trips_for_route: AsyncTripsForRouteResource) -> None:
        self._trips_for_route = trips_for_route

        self.list = async_to_raw_response_wrapper(
            trips_for_route.list,
        )


class TripsForRouteResourceWithStreamingResponse:
    def __init__(self, trips_for_route: TripsForRouteResource) -> None:
        self._trips_for_route = trips_for_route

        self.list = to_streamed_response_wrapper(
            trips_for_route.list,
        )


class AsyncTripsForRouteResourceWithStreamingResponse:
    def __init__(self, trips_for_route: AsyncTripsForRouteResource) -> None:
        self._trips_for_route = trips_for_route

        self.list = async_to_streamed_response_wrapper(
            trips_for_route.list,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["TripsForLocationListParams"]


class TripsForLocationListParams(TypedDict, total=False):
    lat: Required[float]
    """The latitude coordinate of the search center"""

    lat_span: Required[Annotated[float, PropertyInfo(alias="latSpan")]]
    """Latitude span of the search bounding box"""

    lon: Required[float]
    """The longitude coordinate of the search center"""

    lon_span: Required[Annotated[float, PropertyInfo(alias="lonSpan")]]
    """Longitude span of the search bounding box"""

    include_schedule: Annotated[bool, PropertyInfo(alias="includeSchedule")]
    """Whether to include full schedule elements in the tripDetails section.

    Defaults to false.
    """

    include_trip: Annotated[bool, PropertyInfo(alias="includeTrip")]
    """Whether to include full trip elements in the references section.

    Defaults to false.
    """

    time: int
    """Specific time for the query. Defaults to the current time."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["ArrivalAndDepartureRetrieveParams"]


class ArrivalAndDepartureRetrieveParams(TypedDict, total=False):
    service_date: Required[Annotated[int, PropertyInfo(alias="serviceDate")]]

    trip_id: Required[Annotated[str, PropertyInfo(alias="tripId")]]

    stop_sequence: Annotated[int, PropertyInfo(alias="stopSequence")]

    time: int

    vehicle_id: Annotated[str, PropertyInfo(alias="vehicleId")]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .stop import (
    StopResource,
    AsyncStopResource,
    StopResourceWithRawResponse,
    AsyncStopResourceWithRawResponse,
    StopResourceWithStreamingResponse,
    AsyncStopResourceWithStreamingResponse,
)
from .trip import (
    TripResource,
    AsyncTripResource,
    TripResourceWithRawResponse,
    AsyncTripResourceWithRawResponse,
    TripResourceWithStreamingResponse,
    AsyncTripResourceWithStreamingResponse,
)
from .block import (
    BlockResource,
    AsyncBlockResource,
    BlockResourceWithRawResponse,
    AsyncBlockResourceWithRawResponse,
    BlockResourceWithStreamingResponse,
    AsyncBlockResourceWithStreamingResponse,
)
from .route import (
    RouteResource,
    AsyncRouteResource,
    RouteResourceWithRawResponse,
    AsyncRouteResourceWithRawResponse,
    RouteResourceWithStreamingResponse,
    AsyncRouteResourceWithStreamingResponse,
)
from .shape import (
    ShapeResource,
    AsyncShapeResource,
    ShapeResourceWithRawResponse,
    AsyncShapeResourceWithRawResponse,
    ShapeResourceWithStreamingResponse,
    AsyncShapeResourceWithStreamingResponse,
)
from .agency import (
    AgencyResource,
    AsyncAgencyResource,
    AgencyResourceWithRawResponse,
    AsyncAgencyResourceWithRawResponse,
    AgencyResourceWithStreamingResponse,
    AsyncAgencyResourceWithStreamingResponse,
)
from .config import (
    ConfigResource,
    AsyncConfigResource,
    ConfigResourceWithRawResponse,
    AsyncConfigResourceWithRawResponse,
    ConfigResourceWithStreamingResponse,
    AsyncConfigResourceWithStreamingResponse,
)
from .current_time import (
    CurrentTimeResource,
    AsyncCurrentTimeResource,
    CurrentTimeResourceWithRawResponse,
    AsyncCurrentTimeResourceWithRawResponse,
    CurrentTimeResourceWithStreamingResponse,
    AsyncCurrentTimeResourceWithStreamingResponse,
)
from .trip_details import (
    TripDetailsResource,
    AsyncTripDetailsResource,
    TripDetailsResourceWithRawResponse,
    AsyncTripDetailsResourceWithRawResponse,
    TripDetailsResourceWithStreamingResponse,
    AsyncTripDetailsResourceWithStreamingResponse,
)
from .search_for_stop import (
    SearchForStopResource,
    AsyncSearchForStopResource,
    SearchForStopResourceWithRawResponse,
    AsyncSearchForStopResourceWithRawResponse,
    SearchForStopResourceWithStreamingResponse,
    AsyncSearchForStopResourceWithStreamingResponse,
)
from .stops_for_route import (
    StopsForRouteResource,
    AsyncStopsForRouteResource,
    StopsForRouteResourceWithRawResponse,
    AsyncStopsForRouteResourceWithRawResponse,
    StopsForRouteResourceWithStreamingResponse,
    AsyncStopsForRouteResourceWithStreamingResponse,
)
from .trips_for_route import (
    TripsForRouteResource,
    AsyncTripsForRouteResource,
    TripsForRouteResourceWithRawResponse,
    AsyncTripsForRouteResourceWithRawResponse,
    TripsForRouteResourceWithStreamingResponse,
    AsyncTripsForRouteResourceWithStreamingResponse,
)
from .search_for_route import (
    SearchForRouteResource,
    AsyncSearchForRouteResource,
    SearchForRouteResourceWithRawResponse,
    AsyncSearchForRouteResourceWithRawResponse,
    SearchForRouteResourceWithStreamingResponse,
    AsyncSearchForRouteResourceWithStreamingResponse,
)
from .stops_for_agency import (
    StopsForAgencyResource,
    AsyncStopsForAgencyResource,
    StopsForAgencyResourceWithRawResponse,
    AsyncStopsForAgencyResourceWithRawResponse,
    StopsForAgencyResourceWithStreamingResponse,
    AsyncStopsForAgencyResourceWithStreamingResponse,
)
from .trip_for_vehicle import (
    TripForVehicleResource,
    AsyncTripForVehicleResource,
    TripForVehicleResourceWithRawResponse,
    AsyncTripForVehicleResourceWithRawResponse,
    TripForVehicleResourceWithStreamingResponse,
    AsyncTripForVehicleResourceWithStreamingResponse,
)
from .routes_for_agency import (
    RoutesForAgencyResource,
    AsyncRoutesForAgencyResource,
    RoutesForAgencyResourceWithRawResponse,
    AsyncRoutesForAgencyResourceWithRawResponse,
    RoutesForAgencyResourceWithStreamingResponse,
    AsyncRoutesForAgencyResourceWithStreamingResponse,
)
from .schedule_for_stop import (
    ScheduleForStopResource,
    AsyncScheduleForStopResource,
    ScheduleForStopResourceWithRawResponse,
    AsyncScheduleForStopResourceWithRawResponse,
    ScheduleForStopResourceWithStreamingResponse,
    AsyncScheduleForStopResourceWithStreamingResponse,
)
from .schedule_for_route import (
    ScheduleForRouteResource,
    AsyncScheduleForRouteResource,
    ScheduleForRouteResourceWithRawResponse,
    AsyncScheduleForRouteResourceWithRawResponse,
    ScheduleForRouteResourceWithStreamingResponse,
    AsyncScheduleForRouteResourceWithStreamingResponse,
)
from .stops_for_location import (
    StopsForLocationResource,
    AsyncStopsForLocationResource,
    StopsForLocationResourceWithRawResponse,
    AsyncStopsForLocationResourceWithRawResponse,
    StopsForLocationResourceWithStreamingResponse,
    AsyncStopsForLocationResourceWithStreamingResponse,
)
from .trips_for_location import (
    TripsForLocationResource,
    AsyncTripsForLocationResource,
    TripsForLocationResourceWithRawResponse,
    AsyncTripsForLocationResourceWithRawResponse,
    TripsForLocationResourceWithStreamingResponse,
    AsyncTripsForLocationResourceWithStreamingResponse,
)
from .routes_for_location import (
    RoutesForLocationResource,
    AsyncRoutesForLocationResource,
    RoutesForLocationResourceWithRawResponse,
    AsyncRoutesForLocationResourceWithRawResponse,
    RoutesForLocationResourceWithStreamingResponse,
    AsyncRoutesForLocationResourceWithStreamingResponse,
)
from .stop_ids_for_agency import (
    StopIDsForAgencyResource,
    AsyncStopIDsForAgencyResource,
    StopIDsForAgencyResourceWithRawResponse,
    AsyncStopIDsForAgencyResourceWithRawResponse,
    StopIDsForAgencyResourceWithStreamingResponse,
    AsyncStopIDsForAgencyResourceWithStreamingResponse,
)
from .vehicles_for_agency import (
    VehiclesForAgencyResource,
    AsyncVehiclesForAgencyResource,
    VehiclesForAgencyResourceWithRawResponse,
    AsyncVehiclesForAgencyResourceWithRawResponse,
    VehiclesForAgencyResourceWithStreamingResponse,
    AsyncVehiclesForAgencyResourceWithStreamingResponse,
)
from .route_ids_for_agency import (
    RouteIDsForAgencyResource,
    AsyncRouteIDsForAgencyResource,
    RouteIDsForAgencyResourceWithRawResponse,
    AsyncRouteIDsForAgencyResourceWithRawResponse,
    RouteIDsForAgencyResourceWithStreamingResponse,
    AsyncRouteIDsForAgencyResourceWithStreamingResponse,
)
from .arrival_and_departure import (
    ArrivalAndDepartureResource,
    AsyncArrivalAndDepartureResource,
    ArrivalAndDepartureResourceWithRawResponse,
    AsyncArrivalAndDepartureResourceWithRawResponse,
    ArrivalAndDepartureResourceWithStreamingResponse,
    AsyncArrivalAndDepartureResourceWithStreamingResponse,
)
from .agencies_with_coverage import (
    AgenciesWithCoverageResource,
    AsyncAgenciesWithCoverageResource,
    AgenciesWithCoverageResourceWithRawResponse,
    AsyncAgenciesWithCoverageResourceWithRawResponse,
    AgenciesWithCoverageResourceWithStreamingResponse,
    AsyncAgenciesWithCoverageResourceWithStreamingResponse,
)
from .report_problem_with_stop import (
    ReportProblemWithStopResource,
    AsyncReportProblemWithStopResource,
    ReportProblemWithStopResourceWithRawResponse,
    AsyncReportProblemWithStopResourceWithRawResponse,
    ReportProblemWithStopResourceWithStreamingResponse,
    AsyncReportProblemWithStopResourceWithStreamingResponse,
)
from .report_problem_with_trip import (
    ReportProblemWithTripResource,
    AsyncReportProblemWithTripResource,
    ReportProblemWithTripResourceWithRawResponse,
    AsyncReportProblemWithTripResourceWithRawResponse,
    ReportProblemWithTripResourceWithStreamingResponse,
    AsyncReportProblemWithTripResourceWithStreamingResponse,
)

__all__ = [
    "AgenciesWithCoverageResource",
    "AsyncAgenciesWithCoverageResource",
    "AgenciesWithCoverageResourceWithRawResponse",
    "AsyncAgenciesWithCoverageResourceWithRawResponse",
    "AgenciesWithCoverageResourceWithStreamingResponse",
    "AsyncAgenciesWithCoverageResourceWithStreamingResponse",
    "AgencyResource",
    "AsyncAgencyResource",
    "AgencyResourceWithRawResponse",
    "AsyncAgencyResourceWithRawResponse",
    "AgencyResourceWithStreamingResponse",
    "AsyncAgencyResourceWithStreamingResponse",
    "VehiclesForAgencyResource",
    "AsyncVehiclesForAgencyResource",
    "VehiclesForAgencyResourceWithRawResponse",
    "AsyncVehiclesForAgencyResourceWithRawResponse",
    "VehiclesForAgencyResourceWithStreamingResponse",
    "AsyncVehiclesForAgencyResourceWithStreamingResponse",
    "ConfigResource",
    "AsyncConfigResource",
    "ConfigResourceWithRawResponse",
    "AsyncConfigResourceWithRawResponse",
    "ConfigResourceWithStreamingResponse",
    "AsyncConfigResourceWithStreamingResponse",
    "CurrentTimeResource",
    "AsyncCurrentTimeResource",
    "CurrentTimeResourceWithRawResponse",
    "AsyncCurrentTimeResourceWithRawResponse",
    "CurrentTimeResourceWithStreamingResponse",
    "AsyncCurrentTimeResourceWithStreamingResponse",
    "StopsForLocationResource",
    "AsyncStopsForLocationResource",
    "StopsForLocationResourceWithRawResponse",
    "AsyncStopsForLocationResourceWithRawResponse",
    "StopsForLocationResourceWithStreamingResponse",
    "AsyncStopsForLocationResourceWithStreamingResponse",
    "StopsForRouteResource",
    "AsyncStopsForRouteResource",
    "StopsForRouteResourceWithRawResponse",
    "AsyncStopsForRouteResourceWithRawResponse",
    "StopsForRouteResourceWithStreamingResponse",
    "AsyncStopsForRouteResourceWithStreamingResponse",
    "StopsForAgencyResource",
    "AsyncStopsForAgencyResource",
    "StopsForAgencyResourceWithRawResponse",
    "AsyncStopsForAgencyResourceWithRawResponse",
    "StopsForAgencyResourceWithStreamingResponse",
    "AsyncStopsForAgencyResourceWithStreamingResponse",
    "StopResource",
    "AsyncStopResource",
    "StopResourceWithRawResponse",
    "AsyncStopResourceWithRawResponse",
    "StopResourceWithStreamingResponse",
    "AsyncStopResourceWithStreamingResponse",
    "StopIDsForAgencyResource",
    "AsyncStopIDsForAgencyResource",
    "StopIDsForAgencyResourceWithRawResponse",
    "AsyncStopIDsForAgencyResourceWithRawResponse",
    "StopIDsForAgencyResourceWithStreamingResponse",
    "AsyncStopIDsForAgencyResourceWithStreamingResponse",
    "ScheduleForStopResource",
    "AsyncScheduleForStopResource",
    "ScheduleForStopResourceWithRawResponse",
    "AsyncScheduleForStopResourceWithRawResponse",
    "ScheduleForStopResourceWithStreamingResponse",
    "AsyncScheduleForStopResourceWithStreamingResponse",
    "RouteResource",
    "AsyncRouteResource",
    "RouteResourceWithRawResponse",
    "AsyncRouteResourceWithRawResponse",
    "RouteResourceWithStreamingResponse",
    "AsyncRouteResourceWithStreamingResponse",
    "RouteIDsForAgencyResource",
    "AsyncRouteIDsForAgencyResource",
    "RouteIDsForAgencyResourceWithRawResponse",
    "AsyncRouteIDsForAgencyResourceWithRawResponse",
    "RouteIDsForAgencyResourceWithStreamingResponse",
    "AsyncRouteIDsForAgencyResourceWithStreamingResponse",
    "RoutesForLocationResource",
    "AsyncRoutesForLocationResource",
    "RoutesForLocationResourceWithRawResponse",
    "AsyncRoutesForLocationResourceWithRawResponse",
    "RoutesForLocationResourceWithStreamingResponse",
    "AsyncRoutesForLocationResourceWithStreamingResponse",
    "RoutesForAgencyResource",
    "AsyncRoutesForAgencyResource",
    "RoutesForAgencyResourceWithRawResponse",
    "AsyncRoutesForAgencyResourceWithRawResponse",
    "RoutesForAgencyResourceWithStreamingResponse",
    "AsyncRoutesForAgencyResourceWithStreamingResponse",
    "ScheduleForRouteResource",
    "AsyncScheduleForRouteResource",
    "ScheduleForRouteResourceWithRawResponse",
    "AsyncScheduleForRouteResourceWithRawResponse",
    "ScheduleForRouteResourceWithStreamingResponse",
    "AsyncScheduleForRouteResourceWithStreamingResponse",
    "ArrivalAndDepartureResource",
    "AsyncArrivalAndDepartureResource",
    "ArrivalAndDepartureResourceWithRawResponse",
    "AsyncArrivalAndDepartureResourceWithRawResponse",
    "ArrivalAndDepartureResourceWithStreamingResponse",
    "AsyncArrivalAndDepartureResourceWithStreamingResponse",
    "TripResource",
    "AsyncTripResource",
    "TripResourceWithRawResponse",
    "AsyncTripResourceWithRawResponse",
    "TripResourceWithStreamingResponse",
    "AsyncTripResourceWithStreamingResponse",
    "TripsForLocationResource",
    "AsyncTripsForLocationResource",
    "TripsForLocationResourceWithRawResponse",
    "AsyncTripsForLocationResourceWithRawResponse",
    "TripsForLocationResourceWithStreamingResponse",
    "AsyncTripsForLocationResourceWithStreamingResponse",
    "TripDetailsResource",
    "AsyncTripDetailsResource",
    "TripDetailsResourceWithRawResponse",
    "AsyncTripDetailsResourceWithRawResponse",
    "TripDetailsResourceWithStreamingResponse",
    "AsyncTripDetailsResourceWithStreamingResponse",
    "TripForVehicleResource",
    "AsyncTripForVehicleResource",
    "TripForVehicleResourceWithRawResponse",
    "AsyncTripForVehicleResourceWithRawResponse",
    "TripForVehicleResourceWithStreamingResponse",
    "AsyncTripForVehicleResourceWithStreamingResponse",
    "TripsForRouteResource",
    "AsyncTripsForRouteResource",
    "TripsForRouteResourceWithRawResponse",
    "AsyncTripsForRouteResourceWithRawResponse",
    "TripsForRouteResourceWithStreamingResponse",
    "AsyncTripsForRouteResourceWithStreamingResponse",
    "ReportProblemWithStopResource",
    "AsyncReportProblemWithStopResource",
    "ReportProblemWithStopResourceWithRawResponse",
    "AsyncReportProblemWithStopResourceWithRawResponse",
    "ReportProblemWithStopResourceWithStreamingResponse",
    "AsyncReportProblemWithStopResourceWithStreamingResponse",
    "ReportProblemWithTripResource",
    "AsyncReportProblemWithTripResource",
    "ReportProblemWithTripResourceWithRawResponse",
    "AsyncReportProblemWithTripResourceWithRawResponse",
    "ReportProblemWithTripResourceWithStreamingResponse",
    "AsyncReportProblemWithTripResourceWithStreamingResponse",
    "SearchForStopResource",
    "AsyncSearchForStopResource",
    "SearchForStopResourceWithRawResponse",
    "AsyncSearchForStopResourceWithRawResponse",
    "SearchForStopResourceWithStreamingResponse",
    "AsyncSearchForStopResourceWithStreamingResponse",
    "SearchForRouteResource",
    "AsyncSearchForRouteResource",
    "SearchForRouteResourceWithRawResponse",
    "AsyncSearchForRouteResourceWithRawResponse",
    "SearchForRouteResourceWithStreamingResponse",
    "AsyncSearchForRouteResourceWithStreamingResponse",
    "BlockResource",
    "AsyncBlockResource",
    "BlockResourceWithRawResponse",
    "AsyncBlockResourceWithRawResponse",
    "BlockResourceWithStreamingResponse",
    "AsyncBlockResourceWithStreamingResponse",
    "ShapeResource",
    "AsyncShapeResource",
    "ShapeResourceWithRawResponse",
    "AsyncShapeResourceWithRawResponse",
    "ShapeResourceWithStreamingResponse",
    "AsyncShapeResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import stops_for_location_list_params
from .._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from .._utils import (
    maybe_transform,
    async_maybe_transform,
)
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.stops_for_location_list_response import StopsForLocationListResponse

__all__ = ["StopsForLocationResource", "AsyncStopsForLocationResource"]


class StopsForLocationResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> StopsForLocationResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/OneBusAway/python-sdk#accessing-raw-response-data-eg-headers
        """
        return StopsForLocationResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> StopsForLocationResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/OneBusAway/python-sdk#with_streaming_response
        """
        return StopsForLocationResourceWithStreamingResponse(self)

    def list(
        self,
        *,
        lat: float,
        lon: float,
        lat_span: float | NotGiven = NOT_GIVEN,
        lon_span: float | NotGiven = NOT_GIVEN,
        query: str | NotGiven = NOT_GIVEN,
        radius: float | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> StopsForLocationListResponse:
        """
        stops-for-location

        Args:
          lat_span: An alternative to radius to set the search bounding box (optional)

          lon_span: An alternative to radius to set the search bounding box (optional)

          query: A search query string to filter the results

          radius: The radius in meters to search within

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/api/where/stops-for-location.json",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "lat": lat,
                        "lon": lon,
                        "lat_span": lat_span,
                        "lon_span": lon_span,
                        "query": query,
                        "radius": radius,
                    },
                    stops_for_location_list_params.StopsForLocationListParams,
                ),
            ),
            cast_to=StopsForLocationListResponse,
        )


class AsyncStopsForLocationResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncStopsForLocationResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/OneBusAway/python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncStopsForLocationResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncStopsForLocationResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/OneBusAway/python-sdk#with_streaming_response
        """
        return AsyncStopsForLocationResourceWithStreamingResponse(self)

    async def list(
        self,
        *,
        lat: float,
        lon: float,
        lat_span: float | NotGiven = NOT_GIVEN,
        lon_span: float | NotGiven = NOT_GIVEN,
        query: str | NotGiven = NOT_GIVEN,
        radius: float | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> StopsForLocationListResponse:
        """
        stops-for-location

        Args:
          lat_span: An alternative to radius to set the search bounding box (optional)

          lon_span: An alternative to radius to set the search bounding box (optional)

          query: A search query string to filter the results

          radius: The radius in meters to search within

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/api/where/stops-for-location.json",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "lat": lat,
                        "lon": lon,
                        "lat_span": lat_span,
                        "lon_span": lon_span,
                        "query": query,
                        "radius": radius,
                    },
                    stops_for_location_list_params.StopsForLocationListParams,
                ),
            ),
            cast_to=StopsForLocationListResponse,
        )


class StopsForLocationResourceWithRawResponse:
    def __init__(self, stops_for_location: StopsForLocationResource) -> None:
        self._stops_for_location = stops_for_location

        self.list = to_raw_response_wrapper(
            stops_for_location.list,
        )


class AsyncStopsForLocationResourceWithRawResponse:
    def __init__(self, stops_for_location: AsyncStopsForLocationResource) -> None:
        self._stops_for_location = stops_for_location

        self.list = async_to_raw_response_wrapper(
            stops_for_location.list,
        )


class StopsForLocationResourceWithStreamingResponse:
    def __init__(self, stops_for_location: StopsForLocationResource) -> None:
        self._stops_for_location = stops_for_location

        self.list = to_streamed_response_wrapper(
            stops_for_location.list,
        )


class AsyncStopsForLocationResourceWithStreamingResponse:
    def __init__(self, stops_for_location: AsyncStopsForLocationResource) -> None:
        self._stops_for_location = stops_for_location

        self.list = async_to_streamed_response_wrapper(
            stops_for_location.list,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from pydantic import Field as FieldInfo

from .._models import BaseModel
from .shared.references import References
from .shared.response_wrapper import ResponseWrapper

__all__ = [
    "ConfigRetrieveResponse",
    "ConfigRetrieveResponseData",
    "ConfigRetrieveResponseDataEntry",
    "ConfigRetrieveResponseDataEntryGitProperties",
]


class ConfigRetrieveResponseDataEntryGitProperties(BaseModel):
    git_branch: Optional[str] = FieldInfo(alias="git.branch", default=None)

    git_build_host: Optional[str] = FieldInfo(alias="git.build.host", default=None)

    git_build_time: Optional[str] = FieldInfo(alias="git.build.time", default=None)

    git_build_user_email: Optional[str] = FieldInfo(alias="git.build.user.email", default=None)

    git_build_user_name: Optional[str] = FieldInfo(alias="git.build.user.name", default=None)

    git_build_version: Optional[str] = FieldInfo(alias="git.build.version", default=None)

    git_closest_tag_commit_count: Optional[str] = FieldInfo(alias="git.closest.tag.commit.count", default=None)

    git_closest_tag_name: Optional[str] = FieldInfo(alias="git.closest.tag.name", default=None)

    git_commit_id: Optional[str] = FieldInfo(alias="git.commit.id", default=None)

    git_commit_id_abbrev: Optional[str] = FieldInfo(alias="git.commit.id.abbrev", default=None)

    git_commit_id_describe: Optional[str] = FieldInfo(alias="git.commit.id.describe", default=None)

    git_commit_id_describe_short: Optional[str] = FieldInfo(alias="git.commit.id.describe-short", default=None)

    git_commit_message_full: Optional[str] = FieldInfo(alias="git.commit.message.full", default=None)

    git_commit_message_short: Optional[str] = FieldInfo(alias="git.commit.message.short", default=None)

    git_commit_time: Optional[str] = FieldInfo(alias="git.commit.time", default=None)

    git_commit_user_email: Optional[str] = FieldInfo(alias="git.commit.user.email", default=None)

    git_commit_user_name: Optional[str] = FieldInfo(alias="git.commit.user.name", default=None)

    git_dirty: Optional[str] = FieldInfo(alias="git.dirty", default=None)

    git_remote_origin_url: Optional[str] = FieldInfo(alias="git.remote.origin.url", default=None)

    git_tags: Optional[str] = FieldInfo(alias="git.tags", default=None)


class ConfigRetrieveResponseDataEntry(BaseModel):
    id: Optional[str] = None

    git_properties: Optional[ConfigRetrieveResponseDataEntryGitProperties] = FieldInfo(
        alias="gitProperties", default=None
    )

    name: Optional[str] = None

    service_date_from: Optional[str] = FieldInfo(alias="serviceDateFrom", default=None)

    service_date_to: Optional[str] = FieldInfo(alias="serviceDateTo", default=None)


class ConfigRetrieveResponseData(BaseModel):
    entry: ConfigRetrieveResponseDataEntry

    references: References


class ConfigRetrieveResponse(ResponseWrapper):
    data: ConfigRetrieveResponseData



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.


from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["ResponseWrapper"]


class ResponseWrapper(BaseModel):
    code: int

    current_time: int = FieldInfo(alias="currentTime")

    text: str

    version: int



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from onebusaway import OnebusawaySDK, AsyncOnebusawaySDK
from tests.utils import assert_matches_type
from onebusaway.types import (
    ArrivalAndDepartureListResponse,
    ArrivalAndDepartureRetrieveResponse,
)
from onebusaway._utils import parse_datetime

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestArrivalAndDeparture:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_retrieve(self, client: OnebusawaySDK) -> None:
        arrival_and_departure = client.arrival_and_departure.retrieve(
            stop_id="1_75403",
            service_date=0,
            trip_id="tripId",
        )
        assert_matches_type(ArrivalAndDepartureRetrieveResponse, arrival_and_departure, path=["response"])

    @parametrize
    def test_method_retrieve_with_all_params(self, client: OnebusawaySDK) -> None:
        arrival_and_departure = client.arrival_and_departure.retrieve(
            stop_id="1_75403",
            service_date=0,
            trip_id="tripId",
            stop_sequence=0,
            time=0,
            vehicle_id="vehicleId",
        )
        assert_matches_type(ArrivalAndDepartureRetrieveResponse, arrival_and_departure, path=["response"])

    @parametrize
    def test_raw_response_retrieve(self, client: OnebusawaySDK) -> None:
        response = client.arrival_and_departure.with_raw_response.retrieve(
            stop_id="1_75403",
            service_date=0,
            trip_id="tripId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        arrival_and_departure = response.parse()
        assert_matches_type(ArrivalAndDepartureRetrieveResponse, arrival_and_departure, path=["response"])

    @parametrize
    def test_streaming_response_retrieve(self, client: OnebusawaySDK) -> None:
        with client.arrival_and_departure.with_streaming_response.retrieve(
            stop_id="1_75403",
            service_date=0,
            trip_id="tripId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            arrival_and_departure = response.parse()
            assert_matches_type(ArrivalAndDepartureRetrieveResponse, arrival_and_departure, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_retrieve(self, client: OnebusawaySDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `stop_id` but received ''"):
            client.arrival_and_departure.with_raw_response.retrieve(
                stop_id="",
                service_date=0,
                trip_id="tripId",
            )

    @parametrize
    def test_method_list(self, client: OnebusawaySDK) -> None:
        arrival_and_departure = client.arrival_and_departure.list(
            stop_id="1_75403",
        )
        assert_matches_type(ArrivalAndDepartureListResponse, arrival_and_departure, path=["response"])

    @parametrize
    def test_method_list_with_all_params(self, client: OnebusawaySDK) -> None:
        arrival_and_departure = client.arrival_and_departure.list(
            stop_id="1_75403",
            minutes_after=0,
            minutes_before=0,
            time=parse_datetime("2019-12-27T18:11:19.117Z"),
        )
        assert_matches_type(ArrivalAndDepartureListResponse, arrival_and_departure, path=["response"])

    @parametrize
    def test_raw_response_list(self, client: OnebusawaySDK) -> None:
        response = client.arrival_and_departure.with_raw_response.list(
            stop_id="1_75403",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        arrival_and_departure = response.parse()
        assert_matches_type(ArrivalAndDepartureListResponse, arrival_and_departure, path=["response"])

    @parametrize
    def test_streaming_response_list(self, client: OnebusawaySDK) -> None:
        with client.arrival_and_departure.with_streaming_response.list(
            stop_id="1_75403",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            arrival_and_departure = response.parse()
            assert_matches_type(ArrivalAndDepartureListResponse, arrival_and_departure, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_list(self, client: OnebusawaySDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `stop_id` but received ''"):
            client.arrival_and_departure.with_raw_response.list(
                stop_id="",
            )


class TestAsyncArrivalAndDeparture:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    async def test_method_retrieve(self, async_client: AsyncOnebusawaySDK) -> None:
        arrival_and_departure = await async_client.arrival_and_departure.retrieve(
            stop_id="1_75403",
            service_date=0,
            trip_id="tripId",
        )
        assert_matches_type(ArrivalAndDepartureRetrieveResponse, arrival_and_departure, path=["response"])

    @parametrize
    async def test_method_retrieve_with_all_params(self, async_client: AsyncOnebusawaySDK) -> None:
        arrival_and_departure = await async_client.arrival_and_departure.retrieve(
            stop_id="1_75403",
            service_date=0,
            trip_id="tripId",
            stop_sequence=0,
            time=0,
            vehicle_id="vehicleId",
        )
        assert_matches_type(ArrivalAndDepartureRetrieveResponse, arrival_and_departure, path=["response"])

    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncOnebusawaySDK) -> None:
        response = await async_client.arrival_and_departure.with_raw_response.retrieve(
            stop_id="1_75403",
            service_date=0,
            trip_id="tripId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        arrival_and_departure = await response.parse()
        assert_matches_type(ArrivalAndDepartureRetrieveResponse, arrival_and_departure, path=["response"])

    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncOnebusawaySDK) -> None:
        async with async_client.arrival_and_departure.with_streaming_response.retrieve(
            stop_id="1_75403",
            service_date=0,
            trip_id="tripId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            arrival_and_departure = await response.parse()
            assert_matches_type(ArrivalAndDepartureRetrieveResponse, arrival_and_departure, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncOnebusawaySDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `stop_id` but received ''"):
            await async_client.arrival_and_departure.with_raw_response.retrieve(
                stop_id="",
                service_date=0,
                trip_id="tripId",
            )

    @parametrize
    async def test_method_list(self, async_client: AsyncOnebusawaySDK) -> None:
        arrival_and_departure = await async_client.arrival_and_departure.list(
            stop_id="1_75403",
        )
        assert_matches_type(ArrivalAndDepartureListResponse, arrival_and_departure, path=["response"])

    @parametrize
    async def test_method_list_with_all_params(self, async_client: AsyncOnebusawaySDK) -> None:
        arrival_and_departure = await async_client.arrival_and_departure.list(
            stop_id="1_75403",
            minutes_after=0,
            minutes_before=0,
            time=parse_datetime("2019-12-27T18:11:19.117Z"),
        )
        assert_matches_type(ArrivalAndDepartureListResponse, arrival_and_departure, path=["response"])

    @parametrize
    async def test_raw_response_list(self, async_client: AsyncOnebusawaySDK) -> None:
        response = await async_client.arrival_and_departure.with_raw_response.list(
            stop_id="1_75403",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        arrival_and_departure = await response.parse()
        assert_matches_type(ArrivalAndDepartureListResponse, arrival_and_departure, path=["response"])

    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncOnebusawaySDK) -> None:
        async with async_client.arrival_and_departure.with_streaming_response.list(
            stop_id="1_75403",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            arrival_and_departure = await response.parse()
            assert_matches_type(ArrivalAndDepartureListResponse, arrival_and_departure, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_list(self, async_client: AsyncOnebusawaySDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `stop_id` but received ''"):
            await async_client.arrival_and_departure.with_raw_response.list(
                stop_id="",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import trip_for_vehicle_retrieve_params
from .._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from .._utils import (
    maybe_transform,
    async_maybe_transform,
)
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.trip_for_vehicle_retrieve_response import TripForVehicleRetrieveResponse

__all__ = ["TripForVehicleResource", "AsyncTripForVehicleResource"]


class TripForVehicleResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> TripForVehicleResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/OneBusAway/python-sdk#accessing-raw-response-data-eg-headers
        """
        return TripForVehicleResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> TripForVehicleResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/OneBusAway/python-sdk#with_streaming_response
        """
        return TripForVehicleResourceWithStreamingResponse(self)

    def retrieve(
        self,
        vehicle_id: str,
        *,
        include_schedule: bool | NotGiven = NOT_GIVEN,
        include_status: bool | NotGiven = NOT_GIVEN,
        include_trip: bool | NotGiven = NOT_GIVEN,
        time: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> TripForVehicleRetrieveResponse:
        """
        Retrieve trip for a specific vehicle

        Args:
          include_schedule: Determines whether full <schedule/> element is included in the <tripDetails/>
              section. Defaults to false.

          include_status: Determines whether the full <status/> element is included in the <tripDetails/>
              section. Defaults to true.

          include_trip: Determines whether full <trip/> element is included in the <references/>
              section. Defaults to false.

          time: Time parameter to query the system at a specific time (optional).

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not vehicle_id:
            raise ValueError(f"Expected a non-empty value for `vehicle_id` but received {vehicle_id!r}")
        return self._get(
            f"/api/where/trip-for-vehicle/{vehicle_id}.json",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "include_schedule": include_schedule,
                        "include_status": include_status,
                        "include_trip": include_trip,
                        "time": time,
                    },
                    trip_for_vehicle_retrieve_params.TripForVehicleRetrieveParams,
                ),
            ),
            cast_to=TripForVehicleRetrieveResponse,
        )


class AsyncTripForVehicleResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncTripForVehicleResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/OneBusAway/python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncTripForVehicleResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncTripForVehicleResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/OneBusAway/python-sdk#with_streaming_response
        """
        return AsyncTripForVehicleResourceWithStreamingResponse(self)

    async def retrieve(
        self,
        vehicle_id: str,
        *,
        include_schedule: bool | NotGiven = NOT_GIVEN,
        include_status: bool | NotGiven = NOT_GIVEN,
        include_trip: bool | NotGiven = NOT_GIVEN,
        time: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> TripForVehicleRetrieveResponse:
        """
        Retrieve trip for a specific vehicle

        Args:
          include_schedule: Determines whether full <schedule/> element is included in the <tripDetails/>
              section. Defaults to false.

          include_status: Determines whether the full <status/> element is included in the <tripDetails/>
              section. Defaults to true.

          include_trip: Determines whether full <trip/> element is included in the <references/>
              section. Defaults to false.

          time: Time parameter to query the system at a specific time (optional).

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not vehicle_id:
            raise ValueError(f"Expected a non-empty value for `vehicle_id` but received {vehicle_id!r}")
        return await self._get(
            f"/api/where/trip-for-vehicle/{vehicle_id}.json",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "include_schedule": include_schedule,
                        "include_status": include_status,
                        "include_trip": include_trip,
                        "time": time,
                    },
                    trip_for_vehicle_retrieve_params.TripForVehicleRetrieveParams,
                ),
            ),
            cast_to=TripForVehicleRetrieveResponse,
        )


class TripForVehicleResourceWithRawResponse:
    def __init__(self, trip_for_vehicle: TripForVehicleResource) -> None:
        self._trip_for_vehicle = trip_for_vehicle

        self.retrieve = to_raw_response_wrapper(
            trip_for_vehicle.retrieve,
        )


class AsyncTripForVehicleResourceWithRawResponse:
    def __init__(self, trip_for_vehicle: AsyncTripForVehicleResource) -> None:
        self._trip_for_vehicle = trip_for_vehicle

        self.retrieve = async_to_raw_response_wrapper(
            trip_for_vehicle.retrieve,
        )


class TripForVehicleResourceWithStreamingResponse:
    def __init__(self, trip_for_vehicle: TripForVehicleResource) -> None:
        self._trip_for_vehicle = trip_for_vehicle

        self.retrieve = to_streamed_response_wrapper(
            trip_for_vehicle.retrieve,
        )


class AsyncTripForVehicleResourceWithStreamingResponse:
    def __init__(self, trip_for_vehicle: AsyncTripForVehicleResource) -> None:
        self._trip_for_vehicle = trip_for_vehicle

        self.retrieve = async_to_streamed_response_wrapper(
            trip_for_vehicle.retrieve,
        )
